#include "decoder.h"
#include "comparator.h"
#include <stdexcept>
#include <filesystem>

void checkPath(std::string path)
{
	if(!std::filesystem::exists(path))
        throw std::runtime_error("The path " + path + " does not exist!");
    if(std::filesystem::is_directory(path))
        throw std::runtime_error("The path " + path + " does not lead to a file!");
}

int main(int argc, char **argv)
{
	bool printHelp{false};
	if(argc <= 1)
		printHelp = true;
	else if(std::string(argv[1]) == "-h" || std::string(argv[1]) == "--help")
		printHelp = true;
	if(printHelp)
		std::cout << "Use as ./ffExample path/to/first/image path/to/second/image" << std::endl;
		
    try
    {
		auto imageAPath = std::string(argv[1]);
		auto imageBPath = std::string(argv[2]);
        checkPath(imageAPath);
        checkPath(imageBPath);
        
        Decoder decoderA(imageAPath);
        Decoder decoderB(imageBPath);
       
		Comparator comparator(decoderA.getCodecContext());
		comparator.pushImageA(decoderA.getFrame());
		comparator.pushImageB(decoderB.getFrame());
		comparator.printMetrics();
    }
    catch(const std::exception &e)
    {
        std::cerr << e.what() << std::endl;
        return EXIT_FAILURE;
    }
    return EXIT_SUCCESS;
}
